==> templating-8.x-4.0.tar.gz: templating/src/Form/ConfigTemplateSetting.php <==
<?php

namespace Drupal\templating\Form;


use Drupal\Component\Utility\UrlHelper;
use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Url;

/**
 * Edit config variable form.
 */
class ConfigTemplateSetting extends FormBase
{

    protected $step = -1;
    /**
     * {@inheritdoc}
     */
    public function getFormId()
    {
        return 'config_template_settings_form';
    }

    /**
     * {@inheritdoc}
     */
    public function buildForm(array $form, FormStateInterface $form_state, $config_name = '')
    {
        $config_settings = \Drupal::config("template_inline.settings") ;
        $services = \Drupal::service('templating.manager');
        // $themes = $services->getThemeList();
        // $theme_options = [];
        // foreach(array_keys($themes) as $theme){
        //     $theme_options[$theme] = $theme ;
        // }            
        // $form['theme'] = [
        //     '#type' => 'checkboxes',
        //     '#title' => t('Theme'),
        //     '#options' => $theme_options,
        //     '#multiple' => TRUE,
        //     '#required' => TRUE,
        //     '#default_value' =>  ($config_settings->get('theme'))? $config_settings->get('theme'): "" ,
        // ];
        // $form['guide_twig'] = [
        //     '#type' => 'text_format',
        //     '#format' => 'html_code',
        //     '#default_value' =>  ($config_settings->get('guide_twig'))? $config_settings->get('guide_twig'):'',
        // ];
        $form['enabled'] = array(
            '#type' => 'checkbox',
            '#title' => t('Enabled template inline'),
            '#default_value' =>  ($config_settings->get('enabled'))? $config_settings->get('enabled'): false 
        );
        $form['actions'] = ['#type' => 'actions'];
        $form['actions']['submit'] = [
            '#type' => 'submit',
            '#value' => $this->t('Save'),
        ];
   
        $form['actions']['cancel'] = array(
            '#type' => 'link',
            '#title' => $this->t('Back to Template list'),
            '#url' => $this->buildCancelLinkUrl(),
        );
        return $form;

    }


    /**
     * Builds the cancel link url for the form.
     *
     * @return Url
     *   Cancel url
     */
    private function buildCancelLinkUrl()
    {
        $query = $this->getRequest()->query;
        if ($query->has('destination')) {
            $options = UrlHelper::parse($query->get('destination'));
            $url = Url::fromUri('internal:/' . $options['path'], $options);
        } else {
            $url = Url::fromRoute('templating.manager');
        }

        return $url;
    }

    /**
     * {@inheritdoc}
     */
    public function validateForm(array &$form, FormStateInterface $form_state)
    {
    }

    /**
     * {@inheritdoc}
     */
    public function submitForm(array &$form, FormStateInterface $form_state)
    {
        $values = $form_state->getValues();
            // saving section
            $libraries = array();
            // $themes = system_list('theme');
            // foreach ($themes as $key => $value) {
            //   $theme_config = $key.".settings_library";
            //   $config = \Drupal::config( $theme_config);
            //   $spt_table = $config->get('spt_table');
            //   if(!empty($spt_table)){
            //      foreach ($spt_table as $key_lib => $item_lib) {
            //        if($item_lib['status'] == 1){
            //           if(!isset($libraries[$item_lib['name']])){            
            //             $str[$item_lib['name']] =  "{{ attach_library('mz_lib/".$item_lib['name']."') }}<br/>";
            //           }
            //        }
            //      }
            //   }
            // }
        $content_lib =  "<b>Library avalaible </b><pre><code>".implode("",$str)."</pre></code>" ;
        $this->configFactory()->getEditable('template_inline.settings')
                        ->set('enabled', $values['enabled'])
                       // ->set('theme', $values['theme'])
                     //   ->set('content_lib', $content_lib )
                     //   ->set('guide_twig', $values['guide_twig']['value'] )
                        ->save();
    }

}

==> templating-8.x-4.5.tar.gz: templating/src/Form/ConfigTemplateSetting.php <==
<?php

namespace Drupal\templating\Form;


use Drupal\Component\Utility\UrlHelper;
use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Url;

/**
 * Edit config variable form.
 */
class ConfigTemplateSetting extends FormBase
{

    protected $step = -1;
    /**
     * {@inheritdoc}
     */
    public function getFormId()
    {
        return 'config_template_settings_form';
    }

    /**
     * {@inheritdoc}
     */
    public function buildForm(array $form, FormStateInterface $form_state, $config_name = '')
    {
      

        $config_settings = \Drupal::config("template_inline.settings") ;
        $services = \Drupal::service('templating.manager');
       
     
        $form['guide_twig'] = [
            '#type' => 'text_format',
            '#format' => 'html_code',
            '#default_value' =>  ($config_settings->get('guide_twig'))? $config_settings->get('guide_twig'):'',
        ];
        $form['enabled'] = array(
            '#type' => 'checkbox',
            '#title' => t('Disable template inline'),
            '#default_value' =>  ($config_settings->get('disable'))? $config_settings->get('disable'): false 
        );
        $form['actions'] = ['#type' => 'actions'];
        $form['actions']['submit'] = [
            '#type' => 'submit',
            '#value' => $this->t('Save'),
        ];
   
        $form['actions']['cancel'] = array(
            '#type' => 'link',
            '#title' => $this->t('Back to Template list'),
            '#url' => $this->buildCancelLinkUrl(),
        );
        return $form;

    }


    /**
     * Builds the cancel link url for the form.
     *
     * @return Url
     *   Cancel url
     */
    private function buildCancelLinkUrl()
    {
        $query = $this->getRequest()->query;
        if ($query->has('destination')) {
            $options = UrlHelper::parse($query->get('destination'));
            $url = Url::fromUri('internal:/' . $options['path'], $options);
        } else {
          //  $url = Url::fromRoute('templating.manager');
        }

        return $url;
    }

    /**
     * {@inheritdoc}
     */
    public function validateForm(array &$form, FormStateInterface $form_state)
    {
    }

    /**
     * {@inheritdoc}
     */
    public function submitForm(array &$form, FormStateInterface $form_state)
    {
        $values = $form_state->getValues();
            // saving section
      //      $libraries = array();
            // $themes = system_list('theme');
            // foreach ($themes as $key => $value) {
            //   $theme_config = $key.".settings_library";
            //   $config = \Drupal::config( $theme_config);
            //   $spt_table = $config->get('spt_table');
            //   if(!empty($spt_table)){
            //      foreach ($spt_table as $key_lib => $item_lib) {
            //        if($item_lib['status'] == 1){
            //           if(!isset($libraries[$item_lib['name']])){            
            //             $str[$item_lib['name']] =  "{{ attach_library('mz_lib/".$item_lib['name']."') }}<br/>";
            //           }
            //        }
            //      }
            //   }
            // }
        $content_lib =  "" ;
        $this->configFactory()->getEditable('template_inline.settings')
                        ->set('disable', $values['disable'])
                        ->set('content_lib', $content_lib )
                        ->set('guide_twig', $values['guide_twig']['value'] )
                        ->save();
    }

}
